@@ -44,4 +44,11 @@ create_pkg_config_file("Ruby/GnomePrint", package_id,
                        nil, "ruby-gnomeprint2.pc")
 create_makefile_at_srcdir(module_name, (base_dir + "src").to_s,
                           "-DRUBY_GNOMEPRINT2_COMPILATION")
+pkg_config_dir = with_config("pkg-config-dir")
+if pkg_config_dir.is_a?(String)
+  File.open((base_dir + "src" + "Makefile").to_s, "ab") do |makefile|
+    makefile.puts
+    makefile.puts("pkgconfigdir=#{pkg_config_dir}")
+  end
+end
 create_top_makefile
