@@ -8,12 +8,12 @@ if system("which make > /dev/null")
   system("cd #{base_dir.dump} && make > /dev/null") or exit(1)
 end
 
-glib_dir = File.expand_path(File.join(base_dir, "..", "glib"))
-$LOAD_PATH.unshift(glib_dir)
-require 'test/glib-test-init'
+glib_dir = File.expand_path(File.join(base_dir, "..", "glib2"))
+$LOAD_PATH.unshift(File.join(glib_dir, "test"))
+require 'glib-test-init'
 
-$LOAD_PATH.unshift(File.join(glib_dir, "src"))
-$LOAD_PATH.unshift(File.join(glib_dir, "src", "lib"))
+$LOAD_PATH.unshift(File.join(glib_dir, "ext", "glib2"))
+$LOAD_PATH.unshift(File.join(glib_dir, "lib"))
 
 $LOAD_PATH.unshift(File.join(base_dir, "src"))
 $LOAD_PATH.unshift(File.join(base_dir, "src", "lib"))
