@@ -39,5 +39,12 @@ have_library("art_lgpl_2", "art_affine_identity") or exit 1
 create_pkg_config_file("Ruby/Libart2", package_id)
 create_makefile_at_srcdir(module_name, (base_dir + "src").to_s,
                           "-DRUBY_LIBART2_COMPILATION")
+pkg_config_dir = with_config("pkg-config-dir")
+if pkg_config_dir.is_a?(String)
+  File.open((base_dir + "src" + "Makefile").to_s, "ab") do |makefile|
+    makefile.puts
+    makefile.puts("pkgconfigdir=#{pkg_config_dir}")
+  end
+end
 create_top_makefile
 
